=========
Changelog
=========

Version 0.1.0 (2023-1-11)
=========================

* First release on PyPI.

Version 0.1.1 (2023-1-15)
=========================

* Updated documentation
* Small code improvements
* Added PyScaffold and pre-commit

Version 0.1.2 (2023-1-18)
=========================

* Updated several links
* Added pytest test cases with code coverage

Version 0.1.8 (2023-1-30)
=========================

* Added join_hyphenated_words to pdfparser

Version 0.1.15 (2023-2-13)
==========================

* Added SPARQL endpoint functionality

Version 0.1.16 (2023-2-17)
==========================

* Added pipeline description of PDF to NIF

Version 0.1.17 (2023-3-12)
==========================

* Added page number to NIF
* Added lexicon for NIF:lemma

Version 0.1.18 (2023-5-3)
=========================

* Added page reference to NIF:Sentence
